export interface ITemplateConfig {
  title: string;
  version: string;
  updateTime: string;
  description: string;
  language: string;
  languageVersion: string;
  tags: Array<string>;
  source: string;
  productId: string;
  tasks: Array<ITaskFlow | ITaskBatch>;
}

export interface ITaskFlow {
  id: string;
  title: string;
  description: string;
  position: {
    x: number;
    y: number;
  };
  type: "flow";
  parentNode: string;
  parameters: Array<IParameter>;
  edges: Array<IEdge>;
}

export interface ITaskBatch {
  id: string;
  title: string;
  description: string;
  position: {
    x: number;
    y: number;
  };
  type: "batch";
  parameters: Array<IParameter>;
  edges: Array<IEdge>;
}

export interface IParameter {
  hidden: boolean;
  id?: string;
  name: string;
  required: boolean;
  domType: IDomType;
  dataType?: string;
  value: string;
  description: string;
  validators: Array<IValidator>;
  choices: Array<IChoice>;
}

export type IDomType =
  | "pathselect"
  | "datasetselect"
  | "fileselect"
  | "input"
  | "file"
  | "select"
  | "multipleselect"
  | "radio"
  | "checkbox";

// 待定
export type IValidator = {
  regex: string;
  message: string;
};

export interface IChoice {
  key: string;
  value: boolean | string | number;
}

export interface IEdge {
  id: string;
  source: string;
  sourceHandle: string;
  target: string;
  targetHandle: string;
  lable: string;
}

// 提交任务时的动态表单的数据结构
export type IRenderTasks = Array<IRenderTask>;
export type IRenderTask = {
  id: string;
  title: string;
  description: string;
  position: {
    x: number;
    y: number;
  };
  type: "batch";
  parameters: Array<IParameter>;
  edges: Array<IEdge>;
  flows: Array<ITaskFlow>;
};
